package at.xaxa.ledger.ui.category.add

import android.util.Log
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.defaultMinSize
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.AccountBox
import androidx.compose.material.icons.filled.ArrowForward
import androidx.compose.material.icons.filled.Build
import androidx.compose.material.icons.filled.Call
import androidx.compose.material.icons.filled.Check
import androidx.compose.material.icons.filled.Close
import androidx.compose.material.icons.filled.Delete
import androidx.compose.material.icons.filled.Favorite
import androidx.compose.material.icons.filled.Home
import androidx.compose.material.icons.filled.Info
import androidx.compose.material.icons.filled.LocationOn
import androidx.compose.material.icons.filled.Lock
import androidx.compose.material.icons.filled.Notifications
import androidx.compose.material.icons.filled.Share
import androidx.compose.material.icons.filled.ShoppingCart
import androidx.compose.material.icons.filled.Warning
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.ExposedDropdownMenuBox
import androidx.compose.material3.ExposedDropdownMenuDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import at.xaxa.ledger.data.db.Category.CategoryEntity
import at.xaxa.ledger.ui.AppViewModelProvider
import at.xaxa.ledger.ui.ButtonSuccess
import at.xaxa.ledger.ui.category.CategoryViewModel
import at.xaxa.ledger.ui.category.iconNames
import at.xaxa.ledger.ui.category.icons


@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun AddCategory(
    onButtonClick: () -> Unit,
    modifier: Modifier = Modifier,
    categoryViewModel: CategoryViewModel = viewModel(factory = AppViewModelProvider.Factory)
) {

    var name by remember { mutableStateOf("") }
    var selectedIconIndex by remember { mutableStateOf(0) } // Store index of selected icon
    var expanded by remember { mutableStateOf(false) } // Controls dropdown visibility

    /*
    val categories by categoryViewModel.categoryUiState.categories.collectAsState(initial = emptyList())
    val category = categoryViewModel.categoryUi.category
    var expanded by remember { mutableStateOf(false) }*/

    Column(
        modifier = modifier
            .fillMaxSize()
            .padding(16.dp, 0.dp),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        OutlinedTextField(
            value = name,
            onValueChange = { name = it },
            label = { Text("Category Name") },
            modifier = Modifier
                .fillMaxWidth()
        )

        ExposedDropdownMenuBox(
            expanded = expanded,
            onExpandedChange = { expanded = it }
        ) {
            OutlinedTextField(
                value = iconNames[selectedIconIndex], // Show selected icon name
                onValueChange = {},
                label = { Text("Icon") },
                readOnly = true,
                leadingIcon = {
                    Icon(
                        imageVector = icons[selectedIconIndex], // Replace with your desired icon
                        contentDescription = "Leading Icon"
                    )
                },
                trailingIcon = {
                    ExposedDropdownMenuDefaults.TrailingIcon(expanded = expanded)
                },
                modifier = Modifier
                    .menuAnchor()
                    .fillMaxWidth()
            )

            ExposedDropdownMenu(
                expanded = expanded,
                onDismissRequest = { expanded = false }
            ) {
                icons.forEachIndexed { index, icon ->
                    DropdownMenuItem(
                        text = { Text(text = iconNames[index]) }, // Use name from iconNames
                        onClick = {
                            selectedIconIndex = index // Update selected index
                            expanded = false
                        },
                        leadingIcon = {
                            androidx.compose.material3.Icon(
                                imageVector = icon,
                                contentDescription = iconNames[index]
                            )
                        }
                    )
                }
            }
        }

        Box(
            modifier = Modifier
                .fillMaxWidth(),
            contentAlignment = Alignment.Center
        ) {
            ButtonSuccess(
                modifier = Modifier,
                "Add Category",
                onClick = {
                    if (name.isNotBlank()) {
                        val newCategory = CategoryEntity(
                            _id = 0,
                            categoryName = name,
                            icon = selectedIconIndex // Save selected index as the icon ID
                        )

                        categoryViewModel.addCategory(newCategory)
                        onButtonClick()
                    }
                }
            )
        }
    }
}
